package Qt::Gui::QPolygonF;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPolygonF
# file     : QtGui/qpolygon.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QPolygonF

=head1 PUBLIC METHODS

=over

=item   QPolygonF()

=item   QPolygonF(int size)

=item   QPolygonF(const QPolygonF & a)

=item   QPolygonF(const QRectF & r)

=item   QPolygonF(const QPolygon & a)

=item   ~QPolygonF()

=item  QRectF boundingRect()

=item  bool containsPoint(const QPointF & pt, Qt::FillRule fillRule)

=item  QPolygonF intersected(const QPolygonF & r)

=item  bool isClosed()

=item  QPolygonF subtracted(const QPolygonF & r)

=item  QPolygon toPolygon()

=item  void translate(const QPointF & offset)

=item  void translate(qreal dx, qreal dy)

=item  QPolygonF translated(const QPointF & offset)

=item  QPolygonF translated(qreal dx, qreal dy)

=item  QPolygonF united(const QPolygonF & r)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
