package Qt::Gui::QPainter;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPainter
# file     : QtGui/qpainter.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QPainter

=head1 PUBLIC METHODS

=over


=back

=head1 ENUM VALUES

=over

=item Antialiasing

=item TextAntialiasing

=item SmoothPixmapTransform

=item HighQualityAntialiasing

=item NonCosmeticDefaultPen

=item OpaqueHint

=item CompositionMode_SourceOver

=item CompositionMode_DestinationOver

=item CompositionMode_Clear

=item CompositionMode_Source

=item CompositionMode_Destination

=item CompositionMode_SourceIn

=item CompositionMode_DestinationIn

=item CompositionMode_SourceOut

=item CompositionMode_DestinationOut

=item CompositionMode_SourceAtop

=item CompositionMode_DestinationAtop

=item CompositionMode_Xor

=item CompositionMode_Plus

=item CompositionMode_Multiply

=item CompositionMode_Screen

=item CompositionMode_Overlay

=item CompositionMode_Darken

=item CompositionMode_Lighten

=item CompositionMode_ColorDodge

=item CompositionMode_ColorBurn

=item CompositionMode_HardLight

=item CompositionMode_SoftLight

=item CompositionMode_Difference

=item CompositionMode_Exclusion

=item RasterOp_SourceOrDestination

=item RasterOp_SourceAndDestination

=item RasterOp_SourceXorDestination

=item RasterOp_NotSourceAndNotDestination

=item RasterOp_NotSourceOrNotDestination

=item RasterOp_NotSourceXorDestination

=item RasterOp_NotSource

=item RasterOp_NotSourceAndDestination

=item RasterOp_SourceAndNotDestination


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
