package Qt::Gui::QStaticText;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStaticText
# file     : QtGui/qstatictext.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QStaticText

=head1 PUBLIC METHODS

=over

=item   QStaticText()

=item   QStaticText(const QString & text)

=item   QStaticText(const QStaticText & other)

=item   ~QStaticText()

=item  bool operator!=(const QStaticText & arg0)

=item  QStaticText & operator=(const QStaticText & arg0)

=item  bool operator==(const QStaticText & arg0)

=item  QStaticText::PerformanceHint performanceHint()

=item  void prepare(const QTransform & matrix, const QFont & font)

=item  void prepare(const QTransform & matrix, const QFont & font = QFont())

=item  void prepare(const QTransform & matrix = QTransform(), const QFont & font = QFont())

=item  void setPerformanceHint(QStaticText::PerformanceHint performanceHint)

=item  void setText(const QString & text)

=item  void setTextFormat(Qt::TextFormat textFormat)

=item  void setTextOption(const QTextOption & textOption)

=item  void setTextWidth(qreal textWidth)

=item  QSizeF size()

=item  QString text()

=item  Qt::TextFormat textFormat()

=item  QTextOption textOption()

=item  qreal textWidth()


=back

=head1 ENUM VALUES

=over

=item ModerateCaching

=item AggressiveCaching


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
