package Qt::Gui::QFontInfo;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QFontInfo
# file     : QtGui/qfontinfo.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QFontInfo

=head1 PUBLIC METHODS

=over

=item   QFontInfo(const QFont & arg0)

=item   QFontInfo(const QFontInfo & arg0)

=item   ~QFontInfo()

=item  bool bold()

=item  bool exactMatch()

=item  QString family()

=item  bool fixedPitch()

=item  bool italic()

=item  QFontInfo & operator=(const QFontInfo & arg0)

=item  bool overline()

=item  int pixelSize()

=item  int pointSize()

=item  qreal pointSizeF()

=item  bool rawMode()

=item  bool strikeOut()

=item  QFont::Style style()

=item  QFont::StyleHint styleHint()

=item  bool underline()

=item  int weight()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
