package Qt::Gui::QToolTip;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QToolTip
# file     : QtGui/qtooltip.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QToolTip

=head1 PUBLIC METHODS

=over

=item  static QFont font()

=item  static void hideText()

=item  static bool isVisible()

=item  static QPalette palette()

=item  static void setFont(const QFont & arg0)

=item  static void setPalette(const QPalette & arg0)

=item  static void showText(const QPoint & pos, const QString & text, QWidget * w)

=item  static void showText(const QPoint & pos, const QString & text, QWidget * w = 0)

=item  static void showText(const QPoint & pos, const QString & text, QWidget * w, const QRect & rect)

=item  static QString text()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
