package Qt::Gui::QHelpEvent;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QHelpEvent
# file     : QtGui/qevent.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QHelpEvent

=head1 PUBLIC METHODS

=over

=item   QHelpEvent(QHelpEvent::Type type, const QPoint & pos, const QPoint & globalPos)

=item   ~QHelpEvent()

=item  const QPoint & globalPos()

=item  int globalX()

=item  int globalY()

=item  const QPoint & pos()

=item  int x()

=item  int y()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
