package Qt::Gui::QPrintEngine;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPrintEngine
# file     : QtGui/qprintengine.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QPrintEngine

=head1 PUBLIC METHODS

=over

=item   ~QPrintEngine()

=item  bool abort()

=item  int metric(QPaintDevice::PaintDeviceMetric arg0)

=item  bool newPage()

=item  QPrinter::PrinterState printerState()

=item  QVariant property(QPrintEngine::PrintEnginePropertyKey key)

=item  void setProperty(QPrintEngine::PrintEnginePropertyKey key, const QVariant & value)


=back

=head1 ENUM VALUES

=over

=item PPK_CollateCopies

=item PPK_ColorMode

=item PPK_Creator

=item PPK_DocumentName

=item PPK_FullPage

=item PPK_NumberOfCopies

=item PPK_Orientation

=item PPK_OutputFileName

=item PPK_PageOrder

=item PPK_PageRect

=item PPK_PageSize

=item PPK_PaperRect

=item PPK_PaperSource

=item PPK_PrinterName

=item PPK_PrinterProgram

=item PPK_Resolution

=item PPK_SelectionOption

=item PPK_SupportedResolutions

=item PPK_WindowsPageSize

=item PPK_FontEmbedding

=item PPK_SuppressSystemPrintStatus

=item PPK_Duplex

=item PPK_PaperSources

=item PPK_CustomPaperSize

=item PPK_PageMargins

=item PPK_CopyCount

=item PPK_SupportsMultipleCopies

=item PPK_PaperSize

=item PPK_CustomBase


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
