package Qt::Gui::QConicalGradient;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QConicalGradient
# file     : QtGui/qbrush.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QGradient/;
#our @ISA = qw/Qt::Gui::QGradient/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QConicalGradient

=head1 PUBLIC METHODS

=over

=item   QConicalGradient()

=item   QConicalGradient(const QPointF & center, qreal startAngle)

=item   QConicalGradient(qreal cx, qreal cy, qreal startAngle)

=item  qreal angle()

=item  QPointF center()

=item  void setAngle(qreal angle)

=item  void setCenter(const QPointF & center)

=item  void setCenter(qreal x, qreal y)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
