package Qt::Gui::QAccessibleInterfaceEx;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAccessibleInterfaceEx
# file     : QtGui/qaccessible.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QAccessibleInterface/;
#our @ISA = qw/Qt::Gui::QAccessibleInterface/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QAccessibleInterfaceEx

=head1 PUBLIC METHODS

=over

=item  QAccessible2Interface * interface_cast(QAccessible2::InterfaceType arg0)

=item  QVariant invokeMethodEx(QAccessible::Method method, int child, const QVariantList & params)

=item  QVariant virtual_hook(const QVariant & data)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
