package Qt::Gui::QGroupBox;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QGroupBox
# file     : QtGui/qgroupbox.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QWidget/;
#our @ISA = qw/Qt::Gui::QWidget/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QGroupBox

=head1 PUBLIC METHODS

=over

=item   QGroupBox(QWidget * parent)

=item   QGroupBox(QWidget * parent = 0)

=item   QGroupBox(const QString & title, QWidget * parent)

=item   QGroupBox(const QString & title, QWidget * parent = 0)

=item   ~QGroupBox()

=item  QFlags<Qt::AlignmentFlag> alignment()

=item  bool isCheckable()

=item  bool isChecked()

=item  bool isFlat()

=item  QSize minimumSizeHint()

=item  void setAlignment(int alignment)

=item  void setCheckable(bool checkable)

=item  void setChecked(bool checked)

=item  void setFlat(bool flat)

=item  void setTitle(const QString & title)

=item  QString title()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
