package Qt::Gui::QTextFragment;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextFragment
# file     : QtGui/qtextobject.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextFragment

=head1 PUBLIC METHODS

=over

=item   QTextFragment()

=item   QTextFragment(const QTextFragment & o)

=item   QTextFragment(const QTextDocumentPrivate * priv, int f, int fe)

=item  QTextCharFormat charFormat()

=item  int charFormatIndex()

=item  bool contains(int position)

=item  bool isValid()

=item  int length()

=item  bool operator!=(const QTextFragment & o)

=item  bool operator<(const QTextFragment & o)

=item  QTextFragment & operator=(const QTextFragment & o)

=item  bool operator==(const QTextFragment & o)

=item  int position()

=item  QString text()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
