package Qt::Gui::QTextTableCellFormat;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextTableCellFormat
# file     : QtGui/qtextformat.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QTextCharFormat/;
#our @ISA = qw/Qt::Gui::QTextCharFormat/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextTableCellFormat

=head1 PUBLIC METHODS

=over

=item   QTextTableCellFormat()

=item  qreal bottomPadding()

=item  bool isValid()

=item  qreal leftPadding()

=item  qreal rightPadding()

=item  void setBottomPadding(qreal padding)

=item  void setLeftPadding(qreal padding)

=item  void setPadding(qreal padding)

=item  void setRightPadding(qreal padding)

=item  void setTopPadding(qreal padding)

=item  qreal topPadding()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
