package Qt::Gui::QFileIconProvider;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QFileIconProvider
# file     : QtGui/qfileiconprovider.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QFileIconProvider

=head1 PUBLIC METHODS

=over

=item   QFileIconProvider()

=item   ~QFileIconProvider()

=item  QIcon icon(QFileIconProvider::IconType type)

=item  QIcon icon(const QFileInfo & info)

=item  QString type(const QFileInfo & info)


=back

=head1 ENUM VALUES

=over

=item Computer

=item Desktop

=item Trashcan

=item Network

=item Drive

=item Folder

=item File


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
