package Qt::Gui::QPainterPathStroker;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QPainterPathStroker
# file     : QtGui/qpainterpath.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QPainterPathStroker

=head1 PUBLIC METHODS

=over

=item   QPainterPathStroker()

=item   ~QPainterPathStroker()

=item  Qt::PenCapStyle capStyle()

=item  QPainterPath createStroke(const QPainterPath & path)

=item  qreal curveThreshold()

=item  qreal dashOffset()

=item  Qt::PenJoinStyle joinStyle()

=item  qreal miterLimit()

=item  void setCapStyle(Qt::PenCapStyle style)

=item  void setCurveThreshold(qreal threshold)

=item  void setDashOffset(qreal offset)

=item  void setDashPattern(Qt::PenStyle arg0)

=item  void setJoinStyle(Qt::PenJoinStyle style)

=item  void setMiterLimit(qreal length)

=item  void setWidth(qreal width)

=item  qreal width()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
